Welcome to `qualpipe` documentation!
====================================

.. currentmodule:: qualpipe

**Version**: |version| **Date**: |today|

Contents
========

.. toctree::
    :maxdepth: 1

    installation
    introduction
    API reference<reference>
    changelog
    AUTHORS


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
